import * as React from 'react';
import React__default, { PropsWithChildren, JSXElementConstructor, ComponentProps, ReactNode, ComponentType } from 'react';
import { NamespaceStrategies, RepositoryTypeCollection, IndexResources, Repository, Branch, File, Links, Changeset, Group, Me, Plugin, RepositoryRole, HalRepresentation, RepositoryRoleBase, User, Person, Namespace, Tag, Hit, ContentType, RepositoryCreation, BranchDetails } from '@scm-manager/ui-types';

declare type Predicate<P extends Record<any, any> = Record<any, any>> = (props: P) => unknown;
declare type ExtensionRegistration<P extends Record<any, any>, T> = {
    predicate: Predicate<P>;
    extension: T;
    extensionName: string;
    priority: number;
};
declare type ExtensionPointDefinition<N extends string, T, P = undefined> = {
    name: N;
    type: T;
    props: P;
};
declare type BindOptions<Props extends Record<any, any>> = {
    predicate?: Predicate<Props>;
    /**
     * Extensions are ordered by name (ASC).
     */
    extensionName?: string;
    /**
     * Extensions are ordered by priority (DESC).
     */
    priority?: number;
};
/**
 * Binder is responsible for binding plugin extensions to their corresponding extension points.
 * The Binder class is mainly exported for testing, plugins should only use the default export.
 */
declare class Binder {
    name: string;
    extensionPoints: {
        [key: string]: Array<ExtensionRegistration<Record<any, any>, unknown>>;
    };
    constructor(name: string);
    /**
     * Binds an extension to the extension point.
     *
     * @param extensionPoint name of extension point
     * @param extension provided extension
     */
    bind<E extends ExtensionPointDefinition<string, unknown>>(extensionPoint: E["name"], extension: E["type"]): void;
    /**
     * Binds an extension to the extension point.
     *
     * @param extensionPoint name of extension point
     * @param extension provided extension
     * @param predicate to decide if the extension gets rendered for the given props
     * @param extensionName name used for sorting alphabetically on retrieval (ASC)
     */
    bind<E extends ExtensionPointDefinition<string, unknown, any>>(extensionPoint: E["name"], extension: E["type"], predicate?: Predicate<E["props"]>, extensionName?: string): void;
    /**
     * Binds an extension to the extension point.
     *
     * @param extensionPoint name of extension point
     * @param extension provided extension
     * @param options object with additional settings
     */
    bind<E extends ExtensionPointDefinition<string, unknown, any>>(extensionPoint: E["name"], extension: E["type"], options?: BindOptions<E["props"]>): void;
    /**
     * Binds an extension to the extension point.
     *
     * @param extensionPoint name of extension point
     * @param extension provided extension
     * @param predicate to decide if the extension gets rendered for the given props
     * @param options object with additional settings
     */
    bind<E extends ExtensionPointDefinition<string, unknown, any>>(extensionPoint: E["name"], extension: E["type"], predicate?: Predicate<E["props"]>, options?: BindOptions<E["props"]>): void;
    /**
     * Returns the first extension or null for the given extension point and its props.
     *
     * @param extensionPoint name of extension point
     */
    getExtension<E extends ExtensionPointDefinition<string, any>>(extensionPoint: E["name"]): E["type"] | null;
    /**
     * Returns the first extension or null for the given extension point and its props.
     *
     * @param extensionPoint name of extension point
     * @param props of the extension point
     */
    getExtension<E extends ExtensionPointDefinition<string, any, any>>(extensionPoint: E["name"], props: E["props"]): E["type"] | null;
    /**
     * Returns all registered extensions for the given extension point and its props.
     *
     * @param extensionPoint name of extension point
     */
    getExtensions<E extends ExtensionPointDefinition<string, unknown>>(extensionPoint: E["name"]): Array<E["type"]>;
    /**
     * Returns all registered extensions for the given extension point and its props.
     *
     * @param extensionPoint name of extension point
     * @param props of the extension point
     */
    getExtensions<E extends ExtensionPointDefinition<string, unknown, any>>(extensionPoint: E["name"], props: E["props"]): Array<E["type"]>;
    /**
     * Returns true if at least one extension is bound to the extension point and its props.
     */
    hasExtension<E extends ExtensionPointDefinition<string, unknown>>(extensionPoint: E["name"]): boolean;
    /**
     * Returns true if at least one extension is bound to the extension point and its props.
     */
    hasExtension<E extends ExtensionPointDefinition<string, unknown, any>>(extensionPoint: E["name"], props: E["props"]): boolean;
    /**
     * Sort extensions in ascending order, starting with entries with specified extensionName.
     */
    sortExtensions: (a: ExtensionRegistration<Record<any, any>, unknown>, b: ExtensionRegistration<Record<any, any>, unknown>) => 0 | 1 | -1;
}
declare const binder: Binder;

/**
 * The BinderContext should only be used to override the default binder for testing purposes.
 */
declare const BinderContext: React.Context<Binder>;
/**
 * Hook to get the binder from context.
 */
declare const useBinder: () => Binder;

declare type Renderable<P> = React__default.ReactElement | React__default.ComponentType<P>;
declare type RenderableExtensionPointDefinition<Name extends string = string, P = undefined> = ExtensionPointDefinition<Name, Renderable<P>, P>;
declare type SimpleRenderableDynamicExtensionPointDefinition<Prefix extends string, Suffix extends string | undefined, Properties> = RenderableExtensionPointDefinition<Suffix extends string ? `${Prefix}${Suffix}` : `${Prefix}${string}`, Properties>;
/**
 * @deprecated Obsolete type
 */
declare type PropTransformer = (props: object) => object;
declare type BaseProps<E extends RenderableExtensionPointDefinition> = {
    name: E["name"];
    renderAll?: boolean;
    /**
     * @deprecated Obsolete property, do not use
     */
    propTransformer?: PropTransformer;
    wrapper?: boolean;
};
declare type Props<E extends RenderableExtensionPointDefinition> = BaseProps<E> & (E["props"] extends undefined ? {
    props?: E["props"];
} : {
    props: E["props"];
});
/**
 * ExtensionPoint renders components which are bound to an extension point.
 */
declare function ExtensionPoint<E extends RenderableExtensionPointDefinition<string, any> = RenderableExtensionPointDefinition<string, any>>({ name, propTransformer, props, renderAll, wrapper, children }: PropsWithChildren<Props<E>>): JSX.Element | null;

/**
 * @deprecated Use {@link ComponentProps} directly instead
 */
declare type ExtractProps<T extends keyof JSX.IntrinsicElements | JSXElementConstructor<any>> = ComponentProps<T>;

declare type RepositoryCreatorSubFormProps = {
    repository: RepositoryCreation;
    onChange: (repository: RepositoryCreation) => void;
    setValid: (valid: boolean) => void;
    disabled?: boolean;
};
declare type RepositoryCreatorComponentProps = ComponentProps<RepositoryCreator["type"]["component"]>;
/**
 * @deprecated use {@link RepositoryCreator}`["type"]` instead
 */
declare type RepositoryCreatorExtension = RepositoryCreator["type"];
declare type RepositoryCreator = ExtensionPointDefinition<"repos.creator", {
    subtitle: string;
    path: string;
    icon: string;
    label: string;
    component: React__default.ComponentType<{
        namespaceStrategies: NamespaceStrategies;
        repositoryTypes: RepositoryTypeCollection;
        index: IndexResources;
        nameForm: React__default.ComponentType<RepositoryCreatorSubFormProps>;
        informationForm: React__default.ComponentType<RepositoryCreatorSubFormProps>;
    }>;
}>;
declare type RepositoryFlags = RenderableExtensionPointDefinition<"repository.flags", {
    repository: Repository;
    tooltipLocation?: "bottom" | "right" | "top" | "left";
}>;
/**
 * @deprecated use {@link ReposSourcesActionbar}`["props"]` instead
 */
declare type ReposSourcesActionbarExtensionProps = ReposSourcesActionbar["props"];
/**
 * @deprecated use {@link ReposSourcesActionbar} instead
 */
declare type ReposSourcesActionbarExtension = ReposSourcesActionbar;
declare type ReposSourcesActionbar = RenderableExtensionPointDefinition<"repos.sources.actionbar", {
    baseUrl: string;
    revision: string;
    branch: Branch | undefined;
    path: string;
    sources: File;
    repository: Repository;
}>;
/**
 * @deprecated use {@link ReposSourcesEmptyActionbar}`["props"]` instead
 */
declare type ReposSourcesEmptyActionbarExtensionProps = ReposSourcesEmptyActionbar["props"];
/**
 * @deprecated use {@link ReposSourcesEmptyActionbar} instead
 */
declare type ReposSourcesEmptyActionbarExtension = ReposSourcesEmptyActionbar;
declare type ReposSourcesEmptyActionbar = RenderableExtensionPointDefinition<"repos.sources.empty.actionbar", {
    sources: File;
    repository: Repository;
}>;
/**
 * @deprecated use {@link ReposSourcesTreeWrapper}`["props"]` instead
 */
declare type ReposSourcesTreeWrapperProps = ReposSourcesTreeWrapper["props"];
/**
 * @deprecated use {@link ReposSourcesTreeWrapper} instead
 */
declare type ReposSourcesTreeWrapperExtension = ReposSourcesTreeWrapper;
declare type ReposSourcesTreeWrapper = RenderableExtensionPointDefinition<"repos.source.tree.wrapper", {
    repository: Repository;
    directory: File;
    baseUrl: string;
    revision: string;
}>;
declare type ReposSourcesTreeRowProps = {
    repository: Repository;
    file: File;
};
/**
 * @deprecated use {@link ReposSourcesTreeRowRight} instead
 */
declare type ReposSourcesTreeRowRightExtension = ReposSourcesTreeRowRight;
declare type ReposSourcesTreeRowRight = RenderableExtensionPointDefinition<"repos.sources.tree.row.right", ReposSourcesTreeRowProps>;
/**
 * @deprecated use {@link ReposSourcesTreeRowAfter} instead
 */
declare type ReposSourcesTreeRowAfterExtension = ReposSourcesTreeRowAfter;
declare type ReposSourcesTreeRowAfter = RenderableExtensionPointDefinition<"repos.sources.tree.row.after", ReposSourcesTreeRowProps>;
/**
 * @deprecated use {@link PrimaryNavigationLoginButton}`["props"]` instead
 */
declare type PrimaryNavigationLoginButtonProps = PrimaryNavigationLoginButton["props"];
/**
 * use {@link PrimaryNavigationLoginButton} instead
 */
declare type PrimaryNavigationLoginButtonExtension = PrimaryNavigationLoginButton;
declare type PrimaryNavigationLoginButton = RenderableExtensionPointDefinition<"primary-navigation.login", {
    links: Links;
    label: string;
    loginUrl: string;
    from: string;
    to: string;
    className: string;
    content: React__default.ReactNode;
}>;
/**
 * @deprecated use {@link PrimaryNavigationLogoutButtonExtension}`["props"]` instead
 */
declare type PrimaryNavigationLogoutButtonProps = PrimaryNavigationLogoutButton["props"];
/**
 * @deprecated use {@link PrimaryNavigationLogoutButton} instead
 */
declare type PrimaryNavigationLogoutButtonExtension = PrimaryNavigationLogoutButton;
declare type PrimaryNavigationLogoutButton = RenderableExtensionPointDefinition<"primary-navigation.logout", {
    links: Links;
    label: string;
    className: string;
    content: React__default.ReactNode;
}>;
/**
 * @deprecated use {@link SourceExtension}`["props"]` instead
 */
declare type SourceExtensionProps = SourceExtension["props"];
declare type SourceExtension = RenderableExtensionPointDefinition<"repos.sources.extensions", {
    repository: Repository;
    baseUrl: string;
    revision: string;
    extension: string;
    sources: File | undefined;
    path: string;
}>;
/**
 * @deprecated use {@link RepositoryOverviewTop}`["props"]` instead
 */
declare type RepositoryOverviewTopExtensionProps = RepositoryOverviewTop["props"];
/**
 * @deprecated use {@link RepositoryOverviewTop} instead
 */
declare type RepositoryOverviewTopExtension = RepositoryOverviewTop;
declare type RepositoryOverviewTop = RenderableExtensionPointDefinition<"repository.overview.top", {
    page: number;
    search?: string;
    namespace?: string;
}>;
/**
 * @deprecated use {@link RepositoryOverviewLeft} instead
 */
declare type RepositoryOverviewLeftExtension = RepositoryOverviewLeft;
declare type RepositoryOverviewLeft = ExtensionPointDefinition<"repository.overview.left", React__default.ComponentType>;
/**
 * @deprecated use {@link RepositoryOverviewTitle} instead
 */
declare type RepositoryOverviewTitleExtension = RepositoryOverviewTitle;
declare type RepositoryOverviewTitle = RenderableExtensionPointDefinition<"repository.overview.title">;
/**
 * @deprecated use {@link RepositoryOverviewSubtitle} instead
 */
declare type RepositoryOverviewSubtitleExtension = RepositoryOverviewSubtitle;
declare type RepositoryOverviewSubtitle = RenderableExtensionPointDefinition<"repository.overview.subtitle">;
/**
 * Specify options for the repository overview like the page size
 */
declare type RepositoryOverviewListOptionsExtensionPoint = ExtensionPointDefinition<"repository.overview.listOptions", () => {
    pageSize?: number;
    showArchived?: boolean;
}>;
declare type DocumentTitleExtensionPoint = ExtensionPointDefinition<"document.title", {
    documentTitle: string | ((originalTitle: string) => string);
}>;
declare type AdminNavigation = RenderableExtensionPointDefinition<"admin.navigation", {
    links: Links;
    url: string;
}>;
declare type AdminRoute = RenderableExtensionPointDefinition<"admin.route", {
    links: Links;
    url: string;
}>;
declare type AdminSetting = RenderableExtensionPointDefinition<"admin.setting", {
    links: Links;
    url: string;
}>;
/**
 * - can be used to replace the whole description of a changeset
 *
 * @deprecated Use `changeset.description.tokens` instead
 */
declare type ChangesetDescription = RenderableExtensionPointDefinition<"changeset.description", {
    changeset: Changeset;
    value: string;
}>;
/**
 * - Can be used to replace parts of a changeset description with components
 * - Has to be bound with a funktion taking the changeset and the (partial) description and returning `Replacement` objects with the following attributes:
 * - textToReplace: The text part of the description that should be replaced by a component
 * - replacement: The component to take instead of the text to replace
 * - replaceAll: Optional boolean; if set to `true`, all occurances of the text will be replaced (default: `false`)
 */
declare type ChangesetDescriptionTokens = ExtensionPointDefinition<"changeset.description.tokens", (changeset: Changeset, value: string) => Array<{
    textToReplace: string;
    replacement: ReactNode;
    replaceAll?: boolean;
}>, {
    changeset: Changeset;
    value: string;
}>;
declare type ChangesetRight = RenderableExtensionPointDefinition<"changeset.right", {
    repository: Repository;
    changeset: Changeset;
}>;
declare type ChangesetsAuthorSuffix = RenderableExtensionPointDefinition<"changesets.author.suffix", {
    changeset: Changeset;
}>;
declare type ChangesetsContributorTableRow = RenderableExtensionPointDefinition<"changesets.contributor.table.row", {
    changeset: Changeset;
}>;
declare type GroupNavigation = RenderableExtensionPointDefinition<"group.navigation", {
    group: Group;
    url: string;
}>;
declare type GroupRoute = RenderableExtensionPointDefinition<"group.route", {
    group: Group;
    url: string;
}>;
declare type GroupSetting = RenderableExtensionPointDefinition<"group.setting", {
    group: Group;
    url: string;
}>;
/**
 * - Add a new Route to the main Route (scm/)
 * - Props: authenticated?: boolean, links: Links
 */
declare type MainRoute = RenderableExtensionPointDefinition<"main.route", {
    me: Me;
    authenticated?: boolean;
}>;
declare type PluginAvatar = RenderableExtensionPointDefinition<"plugins.plugin-avatar", {
    plugin: Plugin;
}>;
declare type PrimaryNavigation = RenderableExtensionPointDefinition<"primary-navigation", {
    links: Links;
}>;
/**
 * - A placeholder for the first navigation menu.
 * - A PrimaryNavigationLink Component can be used here
 * - Actually this Extension Point is used from the Activity Plugin to display the activities at the first Main Navigation menu.
 */
declare type PrimaryNavigationFirstMenu = RenderableExtensionPointDefinition<"primary-navigation.first-menu", {
    links: Links;
    label: string;
}>;
declare type ProfileRoute = RenderableExtensionPointDefinition<"profile.route", {
    me: Me;
    url: string;
}>;
declare type ProfileSetting = RenderableExtensionPointDefinition<"profile.setting", {
    me?: Me;
    url: string;
    links: Links;
}>;
declare type RepoConfigRoute = RenderableExtensionPointDefinition<"repo-config.route", {
    repository: Repository;
    url: string;
}>;
declare type RepoConfigDetails = RenderableExtensionPointDefinition<"repo-config.details", {
    repository: Repository;
    url: string;
}>;
declare type ReposBranchDetailsInformation = RenderableExtensionPointDefinition<"repos.branch-details.information", {
    repository: Repository;
    branch: Branch;
}>;
/**
 * - Location: At meta data view for file
 * - can be used to render additional meta data line
 * - Props: file: string, repository: Repository, revision: string
 */
declare type ReposContentMetaData = RenderableExtensionPointDefinition<"repos.content.metadata", {
    file: File;
    repository: Repository;
    revision: string;
}>;
declare type ReposCreateNamespace = RenderableExtensionPointDefinition<"repos.create.namespace", {
    label: string;
    helpText: string;
    value: string;
    onChange: (namespace: string) => void;
    errorMessage: string;
    validationError?: boolean;
}>;
declare type ReposSourcesContentActionBar = RenderableExtensionPointDefinition<"repos.sources.content.actionbar", {
    repository: Repository;
    file: File;
    revision: string;
    handleExtensionError: React__default.Dispatch<React__default.SetStateAction<Error | undefined>>;
}>;
declare type RepositoryCodeOverviewContent = RenderableExtensionPointDefinition<"repository.code.overview.content", {
    sources: File;
    repository: Repository;
}>;
declare type RepositoryNavigation = RenderableExtensionPointDefinition<"repository.navigation", {
    repository: Repository;
    url: string;
    indexLinks: Links;
}>;
declare type RepositoryNavigationTopLevel = RenderableExtensionPointDefinition<"repository.navigation.topLevel", {
    repository: Repository;
    url: string;
    indexLinks: Links;
}>;
declare type RepositoryRoleDetailsInformation = RenderableExtensionPointDefinition<"repositoryRole.role-details.information", {
    role: RepositoryRole;
}>;
declare type RepositorySetting = RenderableExtensionPointDefinition<"repository.setting", {
    repository: Repository;
    url: string;
    indexLinks: Links;
}>;
declare type RepositoryAvatar = RenderableExtensionPointDefinition<"repos.repository-avatar", {
    repository: Repository;
}>;
/**
 * - Location: At each repository in repository overview
 * - can be used to add avatar for each repository (e.g., to mark repository type)
 */
declare type PrimaryRepositoryAvatar = RenderableExtensionPointDefinition<"repos.repository-avatar.primary", {
    repository: Repository;
    size: number;
}>;
/**
 * - Location: At bottom of a single repository view
 * - can be used to show detailed information about the repository (how to clone, e.g.)
 */
declare type RepositoryDetailsInformation = RenderableExtensionPointDefinition<"repos.repository-details.information", {
    repository: Repository;
}>;
/**
 * - Location: At sources viewer
 * - can  be used to render a special source that is not an image or a source code
 */
declare type RepositorySourcesView = RenderableExtensionPointDefinition<"repos.sources.view", {
    file: File;
    contentType: string;
    revision: string;
    basePath: string;
}>;
declare type RolesRoute = RenderableExtensionPointDefinition<"roles.route", {
    role: HalRepresentation & RepositoryRoleBase & {
        creationDate?: string;
        lastModified?: string;
    };
    url: string;
}>;
declare type UserRoute = RenderableExtensionPointDefinition<"user.route", {
    user: User;
    url: string;
}>;
declare type UserSetting = RenderableExtensionPointDefinition<"user.setting", {
    user: User;
    url: string;
}>;
/**
 * - Dynamic extension point for custom language-specific renderers
 * - Overrides the default Syntax Highlighter for the given language
 * - Used by the Markdown Plantuml Plugin
 */
declare type MarkdownCodeRenderer<Language extends string | undefined = undefined> = SimpleRenderableDynamicExtensionPointDefinition<"markdown-renderer.code.", Language, {
    language?: Language extends string ? Language : string;
    value: string;
    indexLinks: Links;
}>;
/**
 * - Define custom protocols and their renderers for links in markdown
 *
 * Example:
 * ```markdown
 * [description](myprotocol:somelink)
 * ```
 *
 * ```typescript
 * binder.bind<extensionPoints.MarkdownLinkProtocolRenderer<"myprotocol">>("markdown-renderer.link.protocol", { protocol: "myprotocol", renderer: MyProtocolRenderer })
 * ```
 */
declare type MarkdownLinkProtocolRenderer<Protocol extends string | undefined = undefined> = ExtensionPointDefinition<"markdown-renderer.link.protocol", {
    protocol: Protocol extends string ? Protocol : string;
    renderer: React__default.ComponentType<{
        protocol: Protocol extends string ? Protocol : string;
        href: string;
    }>;
}>;
/**
 * Used to determine an avatar image url from a given {@link Person}.
 *
 * @see https://github.com/scm-manager/scm-gravatar-plugin
 */
declare type AvatarFactory = ExtensionPointDefinition<"avatar.factory", (person: Person) => string | undefined>;
/**
 * - Location: At every changeset (detailed view as well as changeset overview)
 * - can be used to add avatar (such as gravatar) for each changeset
 *
 * @deprecated Has no effect, use {@link AvatarFactory} instead
 */
declare type ChangesetAvatarFactory = ExtensionPointDefinition<"changeset.avatar-factory", (changeset: Changeset) => void>;
declare type MainRedirectProps = {
    me: Me;
    authenticated?: boolean;
};
/**
 * - Extension Point for a link factory that provide the Redirect Link
 * - Actually used from the activity plugin: binder.bind("main.redirect", () => "/activity");
 */
declare type MainRedirect = ExtensionPointDefinition<"main.redirect", (props: MainRedirectProps) => string, MainRedirectProps>;
/**
 * - A Factory function to create markdown [renderer](https://github.com/rexxars/react-markdown#node-types)
 * - The factory function will be called with a renderContext parameter of type Object. this parameter is given as a prop for the {@link MarkdownView} component.
 *
 * @deprecated Use {@link MarkdownCodeRenderer} or {@link MarkdownLinkProtocolRenderer} instead
 */
declare type MarkdownRendererFactory = ExtensionPointDefinition<"markdown-renderer-factory", (renderContext: unknown) => Record<string, React__default.ComponentType<any>>>;
declare type RepositoryCardBeforeTitle = RenderableExtensionPointDefinition<"repository.card.beforeTitle", {
    repository: Repository;
}>;
declare type RepositoryCreationInitialization = RenderableExtensionPointDefinition<"repos.create.initialize", {
    repository: Repository;
    setCreationContextEntry: (key: string, value: any) => void;
    indexResources: Partial<HalRepresentation> & {
        links?: Links;
        version?: string;
        initialization?: string;
    };
}>;
declare type NamespaceTopLevelNavigation = RenderableExtensionPointDefinition<"namespace.navigation.topLevel", {
    namespace: Namespace;
    url: string;
}>;
declare type NamespaceRoute = RenderableExtensionPointDefinition<"namespace.route", {
    namespace: Namespace;
    url: string;
}>;
declare type NamespaceSetting = RenderableExtensionPointDefinition<"namespace.setting", {
    namespace: Namespace;
    url: string;
}>;
declare type RepositoryTagDetailsInformation = RenderableExtensionPointDefinition<"repos.tag-details.information", {
    repository: Repository;
    tag: Tag;
}>;
declare type SearchHitRenderer<Type extends string | undefined = undefined> = RenderableExtensionPointDefinition<Type extends string ? `search.hit.${Type}.renderer` : `search.hit.${string}.renderer`, {
    hit: Hit;
}>;
declare type RepositorySourcesContentDownloadButton = RenderableExtensionPointDefinition<"repos.sources.content.downloadButton", {
    repository: Repository;
    file: File;
}>;
declare type RepositoryRoute = RenderableExtensionPointDefinition<"repository.route", {
    repository: Repository;
    url: string;
    indexLinks: Links;
}>;
declare type RepositoryRedirectProps = {
    namespace: string;
    name: string;
    repository: Repository;
    loading: false;
    error: null;
    repoLink: string;
    indexLinks: Links;
    match: {
        params: {
            namespace: string;
            name: string;
        };
        isExact: boolean;
        path: string;
        url: string;
    };
};
declare type RepositoryRedirect = ExtensionPointDefinition<"repository.redirect", (props: RepositoryRedirectProps) => string, RepositoryRedirectProps>;
declare type InitializationStep<Step extends string | undefined = undefined> = SimpleRenderableDynamicExtensionPointDefinition<"initialization.step.", Step, {
    data: HalRepresentation;
}>;
declare type ContentActionExtensionProps = {
    repository: Repository;
    file: File;
    revision: string;
    handleExtensionError: React__default.Dispatch<React__default.SetStateAction<Error | undefined>>;
    contentType?: ContentType;
    setLoading?: (isLoading: boolean) => void;
};
declare type BaseActionBarOverflowMenuProps = {
    category: string;
    label: string;
    icon: string;
    props?: Record<string | number | symbol, unknown>;
};
declare type ActionMenuProps = BaseActionBarOverflowMenuProps & {
    action: (props: ContentActionExtensionProps) => void;
};
declare type ModalMenuProps = BaseActionBarOverflowMenuProps & {
    modalElement: ComponentType<ContentActionExtensionProps & {
        close: () => void;
    }>;
};
declare type LinkMenuProps = BaseActionBarOverflowMenuProps & {
    link: (props: ContentActionExtensionProps) => string;
};
declare type FileViewActionBarOverflowMenu = ExtensionPointDefinition<"repos.sources.content.actionbar.menu", ActionMenuProps | ModalMenuProps | LinkMenuProps, ContentActionExtensionProps>;
declare type LoginForm = RenderableExtensionPointDefinition<"login.form">;
declare type RepositoryDeleteButton = RenderableExtensionPointDefinition<"repository.deleteButton", {
    repository: Repository;
}>;
declare type RepositoryDangerZone = RenderableExtensionPointDefinition<"repository.dangerZone", {
    repository: Repository;
}>;
declare type RepositoryInformationTableBottom = RenderableExtensionPointDefinition<"repository.information.table.bottom", {
    repository: Repository;
}>;
declare type RepositoryBanner = RenderableExtensionPointDefinition<"repository.banner", {
    repository: Repository;
    url: string;
}>;
declare type UserInformationTableBottom = RenderableExtensionPointDefinition<"user.information.table.bottom", {
    user: User;
}>;
declare type GroupInformationTableBottom = RenderableExtensionPointDefinition<"group.information.table.bottom", {
    group: Group;
}>;
declare type BranchMenuDetailProps = {
    repository: Repository;
    branch: Branch;
};
/**
 * @beta
 * @since 2.46.0
 * @example
 * ```typescript
 * import { Menu } from "@scm-manager/ui-overlays";
 * import { Icon } from "@scm-manager/ui-buttons";
 *
 * binder.bind<extensionPoints.BranchListMenu>(
 *  "branches.list.menu",
 *  <Menu.Link to="/code/sources/etc">
 *   <Icon>code</Icon>
 *   <span>Jump to source</span>
 *  </Menu.Link>
 * )
 * ```
 */
declare type BranchListMenu = RenderableExtensionPointDefinition<"branches.list.menu", BranchMenuDetailProps>;
declare type BranchListDetailProps = {
    repository: Repository;
    branch: Branch;
    branchDetails?: BranchDetails;
};
/**
 * @beta
 * @since 2.46.0
 * @example
 * ```typescript
 * import { Card } from "@scm-manager/ui-layout";
 * import { extensionPoints, binder } from "@scm-manager/ui-extensions";
 *
 * binder.bind<extensionPoints.BranchListDetail>(
 *  "branches.list.detail",
 *  <Card.Details.Detail>
 *   <Card.Details.Detail.Label>Reviewers</Card.Details.Detail.Label>
 *   <Card.Details.Detail.Tag>2 / 3</Card.Details.Detail.Tag>
 *  </Card.Details.Detail>
 * )
 * ```
 */
declare type BranchListDetail = RenderableExtensionPointDefinition<"branches.list.detail", BranchListDetailProps>;

type extensionPoints_RepositoryCreatorComponentProps = RepositoryCreatorComponentProps;
type extensionPoints_RepositoryCreatorExtension = RepositoryCreatorExtension;
type extensionPoints_RepositoryCreator = RepositoryCreator;
type extensionPoints_RepositoryFlags = RepositoryFlags;
type extensionPoints_ReposSourcesActionbarExtensionProps = ReposSourcesActionbarExtensionProps;
type extensionPoints_ReposSourcesActionbarExtension = ReposSourcesActionbarExtension;
type extensionPoints_ReposSourcesActionbar = ReposSourcesActionbar;
type extensionPoints_ReposSourcesEmptyActionbarExtensionProps = ReposSourcesEmptyActionbarExtensionProps;
type extensionPoints_ReposSourcesEmptyActionbarExtension = ReposSourcesEmptyActionbarExtension;
type extensionPoints_ReposSourcesEmptyActionbar = ReposSourcesEmptyActionbar;
type extensionPoints_ReposSourcesTreeWrapperProps = ReposSourcesTreeWrapperProps;
type extensionPoints_ReposSourcesTreeWrapperExtension = ReposSourcesTreeWrapperExtension;
type extensionPoints_ReposSourcesTreeWrapper = ReposSourcesTreeWrapper;
type extensionPoints_ReposSourcesTreeRowProps = ReposSourcesTreeRowProps;
type extensionPoints_ReposSourcesTreeRowRightExtension = ReposSourcesTreeRowRightExtension;
type extensionPoints_ReposSourcesTreeRowRight = ReposSourcesTreeRowRight;
type extensionPoints_ReposSourcesTreeRowAfterExtension = ReposSourcesTreeRowAfterExtension;
type extensionPoints_ReposSourcesTreeRowAfter = ReposSourcesTreeRowAfter;
type extensionPoints_PrimaryNavigationLoginButtonProps = PrimaryNavigationLoginButtonProps;
type extensionPoints_PrimaryNavigationLoginButtonExtension = PrimaryNavigationLoginButtonExtension;
type extensionPoints_PrimaryNavigationLoginButton = PrimaryNavigationLoginButton;
type extensionPoints_PrimaryNavigationLogoutButtonProps = PrimaryNavigationLogoutButtonProps;
type extensionPoints_PrimaryNavigationLogoutButtonExtension = PrimaryNavigationLogoutButtonExtension;
type extensionPoints_PrimaryNavigationLogoutButton = PrimaryNavigationLogoutButton;
type extensionPoints_SourceExtensionProps = SourceExtensionProps;
type extensionPoints_SourceExtension = SourceExtension;
type extensionPoints_RepositoryOverviewTopExtensionProps = RepositoryOverviewTopExtensionProps;
type extensionPoints_RepositoryOverviewTopExtension = RepositoryOverviewTopExtension;
type extensionPoints_RepositoryOverviewTop = RepositoryOverviewTop;
type extensionPoints_RepositoryOverviewLeftExtension = RepositoryOverviewLeftExtension;
type extensionPoints_RepositoryOverviewLeft = RepositoryOverviewLeft;
type extensionPoints_RepositoryOverviewTitleExtension = RepositoryOverviewTitleExtension;
type extensionPoints_RepositoryOverviewTitle = RepositoryOverviewTitle;
type extensionPoints_RepositoryOverviewSubtitleExtension = RepositoryOverviewSubtitleExtension;
type extensionPoints_RepositoryOverviewSubtitle = RepositoryOverviewSubtitle;
type extensionPoints_RepositoryOverviewListOptionsExtensionPoint = RepositoryOverviewListOptionsExtensionPoint;
type extensionPoints_DocumentTitleExtensionPoint = DocumentTitleExtensionPoint;
type extensionPoints_AdminNavigation = AdminNavigation;
type extensionPoints_AdminRoute = AdminRoute;
type extensionPoints_AdminSetting = AdminSetting;
type extensionPoints_ChangesetDescription = ChangesetDescription;
type extensionPoints_ChangesetDescriptionTokens = ChangesetDescriptionTokens;
type extensionPoints_ChangesetRight = ChangesetRight;
type extensionPoints_ChangesetsAuthorSuffix = ChangesetsAuthorSuffix;
type extensionPoints_ChangesetsContributorTableRow = ChangesetsContributorTableRow;
type extensionPoints_GroupNavigation = GroupNavigation;
type extensionPoints_GroupRoute = GroupRoute;
type extensionPoints_GroupSetting = GroupSetting;
type extensionPoints_MainRoute = MainRoute;
type extensionPoints_PluginAvatar = PluginAvatar;
type extensionPoints_PrimaryNavigation = PrimaryNavigation;
type extensionPoints_PrimaryNavigationFirstMenu = PrimaryNavigationFirstMenu;
type extensionPoints_ProfileRoute = ProfileRoute;
type extensionPoints_ProfileSetting = ProfileSetting;
type extensionPoints_RepoConfigRoute = RepoConfigRoute;
type extensionPoints_RepoConfigDetails = RepoConfigDetails;
type extensionPoints_ReposBranchDetailsInformation = ReposBranchDetailsInformation;
type extensionPoints_ReposContentMetaData = ReposContentMetaData;
type extensionPoints_ReposCreateNamespace = ReposCreateNamespace;
type extensionPoints_ReposSourcesContentActionBar = ReposSourcesContentActionBar;
type extensionPoints_RepositoryCodeOverviewContent = RepositoryCodeOverviewContent;
type extensionPoints_RepositoryNavigation = RepositoryNavigation;
type extensionPoints_RepositoryNavigationTopLevel = RepositoryNavigationTopLevel;
type extensionPoints_RepositoryRoleDetailsInformation = RepositoryRoleDetailsInformation;
type extensionPoints_RepositorySetting = RepositorySetting;
type extensionPoints_RepositoryAvatar = RepositoryAvatar;
type extensionPoints_PrimaryRepositoryAvatar = PrimaryRepositoryAvatar;
type extensionPoints_RepositoryDetailsInformation = RepositoryDetailsInformation;
type extensionPoints_RepositorySourcesView = RepositorySourcesView;
type extensionPoints_RolesRoute = RolesRoute;
type extensionPoints_UserRoute = UserRoute;
type extensionPoints_UserSetting = UserSetting;
type extensionPoints_MarkdownCodeRenderer<Language extends string | undefined = undefined> = MarkdownCodeRenderer<Language>;
type extensionPoints_MarkdownLinkProtocolRenderer<Protocol extends string | undefined = undefined> = MarkdownLinkProtocolRenderer<Protocol>;
type extensionPoints_AvatarFactory = AvatarFactory;
type extensionPoints_ChangesetAvatarFactory = ChangesetAvatarFactory;
type extensionPoints_MainRedirect = MainRedirect;
type extensionPoints_MarkdownRendererFactory = MarkdownRendererFactory;
type extensionPoints_RepositoryCardBeforeTitle = RepositoryCardBeforeTitle;
type extensionPoints_RepositoryCreationInitialization = RepositoryCreationInitialization;
type extensionPoints_NamespaceTopLevelNavigation = NamespaceTopLevelNavigation;
type extensionPoints_NamespaceRoute = NamespaceRoute;
type extensionPoints_NamespaceSetting = NamespaceSetting;
type extensionPoints_RepositoryTagDetailsInformation = RepositoryTagDetailsInformation;
type extensionPoints_SearchHitRenderer<Type extends string | undefined = undefined> = SearchHitRenderer<Type>;
type extensionPoints_RepositorySourcesContentDownloadButton = RepositorySourcesContentDownloadButton;
type extensionPoints_RepositoryRoute = RepositoryRoute;
type extensionPoints_RepositoryRedirect = RepositoryRedirect;
type extensionPoints_InitializationStep<Step extends string | undefined = undefined> = InitializationStep<Step>;
type extensionPoints_ContentActionExtensionProps = ContentActionExtensionProps;
type extensionPoints_ActionMenuProps = ActionMenuProps;
type extensionPoints_ModalMenuProps = ModalMenuProps;
type extensionPoints_LinkMenuProps = LinkMenuProps;
type extensionPoints_FileViewActionBarOverflowMenu = FileViewActionBarOverflowMenu;
type extensionPoints_LoginForm = LoginForm;
type extensionPoints_RepositoryDeleteButton = RepositoryDeleteButton;
type extensionPoints_RepositoryDangerZone = RepositoryDangerZone;
type extensionPoints_RepositoryInformationTableBottom = RepositoryInformationTableBottom;
type extensionPoints_RepositoryBanner = RepositoryBanner;
type extensionPoints_UserInformationTableBottom = UserInformationTableBottom;
type extensionPoints_GroupInformationTableBottom = GroupInformationTableBottom;
type extensionPoints_BranchListMenu = BranchListMenu;
type extensionPoints_BranchListDetail = BranchListDetail;
declare namespace extensionPoints {
  export {
    extensionPoints_RepositoryCreatorComponentProps as RepositoryCreatorComponentProps,
    extensionPoints_RepositoryCreatorExtension as RepositoryCreatorExtension,
    extensionPoints_RepositoryCreator as RepositoryCreator,
    extensionPoints_RepositoryFlags as RepositoryFlags,
    extensionPoints_ReposSourcesActionbarExtensionProps as ReposSourcesActionbarExtensionProps,
    extensionPoints_ReposSourcesActionbarExtension as ReposSourcesActionbarExtension,
    extensionPoints_ReposSourcesActionbar as ReposSourcesActionbar,
    extensionPoints_ReposSourcesEmptyActionbarExtensionProps as ReposSourcesEmptyActionbarExtensionProps,
    extensionPoints_ReposSourcesEmptyActionbarExtension as ReposSourcesEmptyActionbarExtension,
    extensionPoints_ReposSourcesEmptyActionbar as ReposSourcesEmptyActionbar,
    extensionPoints_ReposSourcesTreeWrapperProps as ReposSourcesTreeWrapperProps,
    extensionPoints_ReposSourcesTreeWrapperExtension as ReposSourcesTreeWrapperExtension,
    extensionPoints_ReposSourcesTreeWrapper as ReposSourcesTreeWrapper,
    extensionPoints_ReposSourcesTreeRowProps as ReposSourcesTreeRowProps,
    extensionPoints_ReposSourcesTreeRowRightExtension as ReposSourcesTreeRowRightExtension,
    extensionPoints_ReposSourcesTreeRowRight as ReposSourcesTreeRowRight,
    extensionPoints_ReposSourcesTreeRowAfterExtension as ReposSourcesTreeRowAfterExtension,
    extensionPoints_ReposSourcesTreeRowAfter as ReposSourcesTreeRowAfter,
    extensionPoints_PrimaryNavigationLoginButtonProps as PrimaryNavigationLoginButtonProps,
    extensionPoints_PrimaryNavigationLoginButtonExtension as PrimaryNavigationLoginButtonExtension,
    extensionPoints_PrimaryNavigationLoginButton as PrimaryNavigationLoginButton,
    extensionPoints_PrimaryNavigationLogoutButtonProps as PrimaryNavigationLogoutButtonProps,
    extensionPoints_PrimaryNavigationLogoutButtonExtension as PrimaryNavigationLogoutButtonExtension,
    extensionPoints_PrimaryNavigationLogoutButton as PrimaryNavigationLogoutButton,
    extensionPoints_SourceExtensionProps as SourceExtensionProps,
    extensionPoints_SourceExtension as SourceExtension,
    extensionPoints_RepositoryOverviewTopExtensionProps as RepositoryOverviewTopExtensionProps,
    extensionPoints_RepositoryOverviewTopExtension as RepositoryOverviewTopExtension,
    extensionPoints_RepositoryOverviewTop as RepositoryOverviewTop,
    extensionPoints_RepositoryOverviewLeftExtension as RepositoryOverviewLeftExtension,
    extensionPoints_RepositoryOverviewLeft as RepositoryOverviewLeft,
    extensionPoints_RepositoryOverviewTitleExtension as RepositoryOverviewTitleExtension,
    extensionPoints_RepositoryOverviewTitle as RepositoryOverviewTitle,
    extensionPoints_RepositoryOverviewSubtitleExtension as RepositoryOverviewSubtitleExtension,
    extensionPoints_RepositoryOverviewSubtitle as RepositoryOverviewSubtitle,
    extensionPoints_RepositoryOverviewListOptionsExtensionPoint as RepositoryOverviewListOptionsExtensionPoint,
    extensionPoints_DocumentTitleExtensionPoint as DocumentTitleExtensionPoint,
    extensionPoints_AdminNavigation as AdminNavigation,
    extensionPoints_AdminRoute as AdminRoute,
    extensionPoints_AdminSetting as AdminSetting,
    extensionPoints_ChangesetDescription as ChangesetDescription,
    extensionPoints_ChangesetDescriptionTokens as ChangesetDescriptionTokens,
    extensionPoints_ChangesetRight as ChangesetRight,
    extensionPoints_ChangesetsAuthorSuffix as ChangesetsAuthorSuffix,
    extensionPoints_ChangesetsContributorTableRow as ChangesetsContributorTableRow,
    extensionPoints_GroupNavigation as GroupNavigation,
    extensionPoints_GroupRoute as GroupRoute,
    extensionPoints_GroupSetting as GroupSetting,
    extensionPoints_MainRoute as MainRoute,
    extensionPoints_PluginAvatar as PluginAvatar,
    extensionPoints_PrimaryNavigation as PrimaryNavigation,
    extensionPoints_PrimaryNavigationFirstMenu as PrimaryNavigationFirstMenu,
    extensionPoints_ProfileRoute as ProfileRoute,
    extensionPoints_ProfileSetting as ProfileSetting,
    extensionPoints_RepoConfigRoute as RepoConfigRoute,
    extensionPoints_RepoConfigDetails as RepoConfigDetails,
    extensionPoints_ReposBranchDetailsInformation as ReposBranchDetailsInformation,
    extensionPoints_ReposContentMetaData as ReposContentMetaData,
    extensionPoints_ReposCreateNamespace as ReposCreateNamespace,
    extensionPoints_ReposSourcesContentActionBar as ReposSourcesContentActionBar,
    extensionPoints_RepositoryCodeOverviewContent as RepositoryCodeOverviewContent,
    extensionPoints_RepositoryNavigation as RepositoryNavigation,
    extensionPoints_RepositoryNavigationTopLevel as RepositoryNavigationTopLevel,
    extensionPoints_RepositoryRoleDetailsInformation as RepositoryRoleDetailsInformation,
    extensionPoints_RepositorySetting as RepositorySetting,
    extensionPoints_RepositoryAvatar as RepositoryAvatar,
    extensionPoints_PrimaryRepositoryAvatar as PrimaryRepositoryAvatar,
    extensionPoints_RepositoryDetailsInformation as RepositoryDetailsInformation,
    extensionPoints_RepositorySourcesView as RepositorySourcesView,
    extensionPoints_RolesRoute as RolesRoute,
    extensionPoints_UserRoute as UserRoute,
    extensionPoints_UserSetting as UserSetting,
    extensionPoints_MarkdownCodeRenderer as MarkdownCodeRenderer,
    extensionPoints_MarkdownLinkProtocolRenderer as MarkdownLinkProtocolRenderer,
    extensionPoints_AvatarFactory as AvatarFactory,
    extensionPoints_ChangesetAvatarFactory as ChangesetAvatarFactory,
    extensionPoints_MainRedirect as MainRedirect,
    extensionPoints_MarkdownRendererFactory as MarkdownRendererFactory,
    extensionPoints_RepositoryCardBeforeTitle as RepositoryCardBeforeTitle,
    extensionPoints_RepositoryCreationInitialization as RepositoryCreationInitialization,
    extensionPoints_NamespaceTopLevelNavigation as NamespaceTopLevelNavigation,
    extensionPoints_NamespaceRoute as NamespaceRoute,
    extensionPoints_NamespaceSetting as NamespaceSetting,
    extensionPoints_RepositoryTagDetailsInformation as RepositoryTagDetailsInformation,
    extensionPoints_SearchHitRenderer as SearchHitRenderer,
    extensionPoints_RepositorySourcesContentDownloadButton as RepositorySourcesContentDownloadButton,
    extensionPoints_RepositoryRoute as RepositoryRoute,
    extensionPoints_RepositoryRedirect as RepositoryRedirect,
    extensionPoints_InitializationStep as InitializationStep,
    extensionPoints_ContentActionExtensionProps as ContentActionExtensionProps,
    extensionPoints_ActionMenuProps as ActionMenuProps,
    extensionPoints_ModalMenuProps as ModalMenuProps,
    extensionPoints_LinkMenuProps as LinkMenuProps,
    extensionPoints_FileViewActionBarOverflowMenu as FileViewActionBarOverflowMenu,
    extensionPoints_LoginForm as LoginForm,
    extensionPoints_RepositoryDeleteButton as RepositoryDeleteButton,
    extensionPoints_RepositoryDangerZone as RepositoryDangerZone,
    extensionPoints_RepositoryInformationTableBottom as RepositoryInformationTableBottom,
    extensionPoints_RepositoryBanner as RepositoryBanner,
    extensionPoints_UserInformationTableBottom as UserInformationTableBottom,
    extensionPoints_GroupInformationTableBottom as GroupInformationTableBottom,
    extensionPoints_BranchListMenu as BranchListMenu,
    extensionPoints_BranchListDetail as BranchListDetail,
  };
}

export { Binder, BinderContext, ExtensionPoint, ExtensionPointDefinition, ExtractProps, RenderableExtensionPointDefinition, SimpleRenderableDynamicExtensionPointDefinition, binder, extensionPoints, useBinder };
