// src/binder.ts
function isBindOptions(input) {
  return typeof input !== "string" && typeof input !== "function" && typeof input === "object";
}
var Binder = class {
  constructor(name) {
    this.sortExtensions = (a, b) => {
      const regA = a.extensionName ? a.extensionName.toUpperCase() : "";
      const regB = b.extensionName ? b.extensionName.toUpperCase() : "";
      if (a.priority > b.priority) {
        return -1;
      } else if (a.priority < b.priority) {
        return 1;
      } else if (regA === "" && regB !== "") {
        return 1;
      } else if (regA !== "" && regB === "") {
        return -1;
      } else if (regA > regB) {
        return 1;
      } else if (regA < regB) {
        return -1;
      }
      return 0;
    };
    this.name = name;
    this.extensionPoints = {};
  }
  bind(extensionPoint, extension, predicateOrOptions, extensionNameOrOptions) {
    let predicate = () => true;
    let priority = 0;
    if (isBindOptions(predicateOrOptions)) {
      if (predicateOrOptions.predicate) {
        predicate = predicateOrOptions.predicate;
      }
      if (predicateOrOptions.extensionName) {
        extensionNameOrOptions = predicateOrOptions.extensionName;
      }
      if (typeof predicateOrOptions.priority === "number") {
        priority = predicateOrOptions.priority;
      }
    } else if (predicateOrOptions) {
      predicate = predicateOrOptions;
      if (isBindOptions(extensionNameOrOptions)) {
        if (typeof extensionNameOrOptions.priority === "number") {
          priority = extensionNameOrOptions.priority;
        }
        if (extensionNameOrOptions == null ? void 0 : extensionNameOrOptions.extensionName) {
          extensionNameOrOptions = extensionNameOrOptions.extensionName;
        } else {
          extensionNameOrOptions = void 0;
        }
      }
    }
    if (!this.extensionPoints[extensionPoint]) {
      this.extensionPoints[extensionPoint] = [];
    }
    const registration = {
      predicate,
      extension,
      extensionName: extensionNameOrOptions ? extensionNameOrOptions : "",
      priority
    };
    this.extensionPoints[extensionPoint].push(registration);
  }
  getExtension(extensionPoint, props) {
    const extensions = this.getExtensions(extensionPoint, props);
    if (extensions.length > 0) {
      return extensions[0];
    }
    return null;
  }
  getExtensions(extensionPoint, props) {
    let registrations = this.extensionPoints[extensionPoint] || [];
    registrations = registrations.filter((reg) => reg.predicate(props != null ? props : {}));
    registrations.sort(this.sortExtensions);
    return registrations.map((reg) => reg.extension);
  }
  hasExtension(extensionPoint, props) {
    return this.getExtensions(extensionPoint, props).length > 0;
  }
};
var binder = new Binder("default");
var binder_default = binder;

// src/useBinder.ts
import { createContext, useContext } from "react";
var BinderContext = createContext(binder_default);
var useBinder = () => {
  return useContext(BinderContext);
};
var useBinder_default = useBinder;

// src/ExtensionPoint.tsx
import React from "react";
function createInstance(Component, props, key) {
  if (React.isValidElement(Component)) {
    return React.cloneElement(Component, {
      ...props,
      ...Component.props,
      key
    });
  }
  return /* @__PURE__ */ React.createElement(Component, {
    ...props,
    key
  });
}
var renderAllExtensions = (binder2, name, props) => {
  const extensions = binder2.getExtensions(name, props);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, extensions.map((cmp, index) => createInstance(cmp, props, index)));
};
var renderWrapperExtensions = (binder2, name, props) => {
  const extensions = binder2.getExtensions(name, props);
  extensions.reverse();
  let instance = null;
  extensions.forEach((cmp, index) => {
    let instanceProps = props;
    if (instance) {
      instanceProps = { ...props, children: instance };
    }
    instance = createInstance(cmp, instanceProps, index);
  });
  return instance;
};
var renderSingleExtension = (binder2, name, props) => {
  const cmp = binder2.getExtension(name, props);
  if (!cmp) {
    return null;
  }
  return createInstance(cmp, props);
};
var renderDefault = (children) => {
  if (children) {
    return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
  }
  return null;
};
var createRenderProps = (propTransformer, props) => {
  const transform = (untransformedProps) => {
    if (!propTransformer) {
      return untransformedProps;
    }
    return propTransformer(untransformedProps);
  };
  return transform(props || {});
};
function ExtensionPoint({ name, propTransformer, props, renderAll, wrapper, children }) {
  const binder2 = useBinder_default();
  const renderProps = createRenderProps(propTransformer, {
    ...props || {},
    children
  });
  if (!binder2.hasExtension(name, renderProps)) {
    return renderDefault(children);
  } else if (renderAll) {
    if (wrapper) {
      return renderWrapperExtensions(binder2, name, renderProps);
    }
    return renderAllExtensions(binder2, name, renderProps);
  }
  return renderSingleExtension(binder2, name, renderProps);
}

// src/extensionPoints.tsx
var extensionPoints_exports = {};
export {
  Binder,
  BinderContext,
  ExtensionPoint,
  binder_default as binder,
  extensionPoints_exports as extensionPoints,
  useBinder
};
